#!/usr/bin/env python

"""Tests for `keycloak_django_utils` package."""


import unittest

from keycloak_django_utils import keycloak_django_utils


class TestKeycloak_django_utils(unittest.TestCase):
    """Tests for `keycloak_django_utils` package."""

    def setUp(self):
        """Set up test fixtures, if any."""

    def tearDown(self):
        """Tear down test fixtures, if any."""

    def test_000_something(self):
        """Test something."""
